@@ -18,17 +18,26 @@ def _find_plugin(directory, name):
     for path, dirs, files in os.walk(directory):
         path = path[n:]
         for f in files:
+            if f.endswith(".yaml"):
+                if f[:-5] == name:
+                    return False, os.path.join(directory, path, f)
+
             if f.endswith(".py"):
                 p = os.path.join(path, f[:-3])
                 if p[0] != "/":
                     p = "/" + p
                 if p[1:].replace("/", "-").replace("_", "-") == name:
-                    return p.replace("/", ".")
+                    return True, p.replace("/", ".")
+
     raise Exception("Cannot find plugin '%s' in %s" % (name, directory))
 
 
-def find_plugin(directory, name):
+def find_plugin(directory, name, module_callback, yaml_callcack):
     if (directory, name) not in CACHE:
         CACHE[(directory, name)] = _find_plugin(directory, name)
 
-    return CACHE[(directory, name)]
+    code, plugin = CACHE[(directory, name)]
+    if code:
+        return module_callback(plugin)
+    else:
+        return yaml_callcack(plugin)
