@@ -9,7 +9,7 @@
 
 import os
 from .base import FileSource
-from climetlab.core.caching import temp_file
+from climetlab.core.caching import cache_file
 import requests
 from tqdm import tqdm
 
@@ -20,7 +20,7 @@ class Url(FileSource):
         super().__init__(**kwargs)
 
         _, extension = os.path.splitext(url)
-        self.path = temp_file("Url", url, extension=extension)
+        self.path = cache_file("Url", url, extension=extension)
 
         if not os.path.exists(self.path):
             print("Downloading", url)
